| Safe Haskell | None |
|---|---|
| Language | Haskell98 |
Satchmo.Counting.Direct
Description
functions in this module have no extra variables but exponential cost.
satchmo-2.9.4: SAT encoding monad
| Safe Haskell | None |
|---|---|
| Language | Haskell98 |
Satchmo.Counting.Direct
Description
functions in this module have no extra variables but exponential cost.