| Safe Haskell | None |
|---|---|
| Language | Haskell98 |
Satchmo.Data
Description
this module just defines types for formulas, it is not meant to contain efficient implementations for formula manipulation.
satchmo-2.9.7.3: SAT encoding monad
| Safe Haskell | None |
|---|---|
| Language | Haskell98 |
Satchmo.Data
Description
this module just defines types for formulas, it is not meant to contain efficient implementations for formula manipulation.